@@ -7,8 +7,8 @@
 
 import plotly.graph_objects as go
 from collections import Counter
-import game_parser
-import find_opening
+from chess_graph import game_parser
+from chess_graph import find_opening
 
 
 
